@@ -1843,7 +1843,8 @@ GSList* gok_spy_append_node (GSList* nodes,
 			} while ((j < 3) && len);
 			AccessibleText_unref (text);
 		}
-		if (g_utf8_strchr(gs,-1,GECKO_EMBEDDED_OBJECT_CHAR)){
+		if (g_utf8_validate (gs, -1, NULL) &&
+		  g_utf8_strchr(gs,-1,GECKO_EMBEDDED_OBJECT_CHAR)){
 			/* We probably have a complex document, where text can contain 
 			utf-8 embed characters to denote the presence of an object 
 			within a region of text. (see mozilla a11y docs). We can safely
